@@ -1,4 +1,4 @@
-use android_tools::java_tools::{android_dir, AabKey, Keyalg, Keytool};
+use android_tools::java_tools::{android_dir, AabKey, KeyAlgorithm, Keytool};
 
 #[test]
 /// The [`keytool`] command is a key and certificate management utility. It enables users to administer
@@ -43,7 +43,7 @@ fn test_create_keystore_with_keytool() {
         .keypass(&key.key_pass)
         .storepass(&key.key_pass)
         .dname(&["CN=Android Debug,O=Android,C=US".to_owned()])
-        .keyalg(Keyalg::RSA)
+        .keyalg(KeyAlgorithm::RSA)
         .keysize(2048)
         .validity(10000)
         .run()
